# Julie CPA Queue Report (20251230_065908)

### sample_ph_fin_01.csv
- [TAX][REVIEW][P1] IRS PAYMENT (-1200.0) | Due: 2025-12-04 | Missing: | Next: | Evidence: Source: sample_ph_fin_01.csv
- [PAY][REVIEW][P2] ADP PAYROLL FEE (-89.0) | Due: 2025-12-05 | Missing: | Next: | Evidence: Source: sample_ph_fin_01.csv
- [CLIENT][REVIEW][P1] RENT PAYMENT (-3200.0) | Due: 2025-12-07 | Missing: | Next: | Evidence: Source: sample_ph_fin_01.csv
- [CLIENT][REVIEW][P1] CLIENT DEPOSIT (4500.0) | Due: 2025-12-08 | Missing: | Next: | Evidence: Source: sample_ph_fin_01.csv